@@ -23,50 +23,52 @@
 #ifndef OKTETA_KCURSOR_H
 #define OKTETA_KCURSOR_H
 
+
 // lib
 #include "kadds.h"
 // Qt
-#include <QPixmap>
+#include <QtGui/QPixmap>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 /**
- * @author Friedrich W. H. Kossebau
- */
+  *@author Friedrich W. H. Kossebau
+  */
 class KCursor
 {
-public:
+  public:
     KCursor();
     virtual ~KCursor();
 
-public:
+  public:
     /** sets size of the full cursor */
-    void setSize(PixelX Width, PixelY Height, qreal devicePixelRatio);
+    void setSize( PixelX Width, PixelY Height );
     /** sets the shape of the cursor to be drawn */
-    void setShape(PixelX X, PixelX W, qreal devicePixelRatio);
+    void setShape( PixelX X, PixelX W );
 
-public: // access
-    QPixmap& onPixmap();
-    QPixmap& offPixmap();
+  public: // access
+    QPixmap &onPixmap();
+    QPixmap &offPixmap();
     PixelX cursorX() const;
-    PixelX shapeX() const;
-    PixelX shapeW() const;
+    PixelX cursorW() const;
 
-protected:
+
+  protected:
     QPixmap OnPixmap;
     QPixmap OffPixmap;
 
-    PixelX CursorX = 0;
-    PixelX ShapeX = -1;
-    PixelX ShapeW = -1;
+    PixelX CursorX;
+    PixelX CursorW;
 };
 
-inline QPixmap& KCursor::onPixmap()  { return OnPixmap; }
-inline QPixmap& KCursor::offPixmap() { return OffPixmap; }
+
+inline QPixmap &KCursor::onPixmap()  { return OnPixmap; }
+inline QPixmap &KCursor::offPixmap() { return OffPixmap; }
 
 inline PixelX KCursor::cursorX() const { return CursorX; }
-inline PixelX KCursor::shapeX() const { return ShapeX; }
-inline PixelX KCursor::shapeW() const { return ShapeW; }
+inline PixelX KCursor::cursorW() const { return CursorW; }
 
 }
 
