@@ -1,34 +1,43 @@
 /*
  *    This file is part of the Okteta Kasten module, made within the KDE community.
  *
- *    SPDX-FileCopyrightText: 2012 Alex Richardson <alex.richardson@gmx.de>
+ *    Copyright 2012  Alex Richardson <alex.richardson@gmx.de>
  *
- *    SPDX-License-Identifier: LGPL-2.1-or-later
+ *    This library is free software; you can redistribute it and/or
+ *    modify it under the terms of the GNU Lesser General Public
+ *    License as published by the Free Software Foundation; either
+ *    version 2.1 of the License, or (at your option) any later version.
+ *
+ *    This library is distributed in the hope that it will be useful,
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *    Lesser General Public License for more details.
+ *
+ *    You should have received a copy of the GNU Lesser General Public
+ *    License along with this library; if not, write to the Free Software
+ *    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <QTest>
-#include <QSignalSpy>
 
-#include "view/structures/datatypes/array/arraydatainformation.hpp"
-#include "view/structures/datatypes/array/primitivearraydata.hpp"
-#include "view/structures/datatypes/topleveldatainformation.hpp"
-#include "view/structures/datatypes/primitive/primitivetemplateinfo.hpp"
-#include "view/structures/datatypes/primitivefactory.hpp"
-#include "view/structures/datatypes/structuredatainformation.hpp"
+#include <QtTest>
+
+#include "view/structures/datatypes/array/arraydatainformation.h"
+#include "view/structures/datatypes/array/primitivearraydata.h"
+#include "view/structures/datatypes/topleveldatainformation.h"
+#include "view/structures/datatypes/primitive/primitivetemplateinfo.h"
+#include "view/structures/datatypes/primitivefactory.h"
+#include "view/structures/datatypes/structuredatainformation.h"
 
 class ArrayDataInformationTest : public QObject
 {
     Q_OBJECT
-
 private:
     void testResizeHelper(ArrayDataInformation* array, TopLevelDataInformation* top);
-
 private Q_SLOTS:
     void initTestCase();
     void testResize();
     void testResize_data();
     void cleanupTestCase();
-
 private:
     ArrayDataInformation* primitive;
     ArrayDataInformation* complex;
@@ -42,10 +51,10 @@ void ArrayDataInformationTest::initTestCase()
 {
     qRegisterMetaType<const DataInformation*>();
     qRegisterMetaType<DataInformation*>();
-    LoggerWithContext lwc(nullptr, QString());
+    LoggerWithContext lwc(0, QString());
 
-    primitive = new ArrayDataInformation(QStringLiteral("primitives"), 0,
-                                         PrimitiveFactory::newInstance(QStringLiteral("child"), PrimitiveDataType::UInt32, lwc));
+    primitive = new ArrayDataInformation(QLatin1String("primitives"), 0,
+            PrimitiveFactory::newInstance(QLatin1String("child"), Type_UInt32, lwc));
     primitiveSize = 32;
     primitiveTop = new TopLevelDataInformation(primitive);
 
@@ -67,13 +76,13 @@ void ArrayDataInformationTest::initTestCase()
     QCOMPARE(primitive->topLevelDataInformation(), primitiveTop);
 
     QVector<DataInformation*> structsChildren;
-    structsChildren << PrimitiveFactory::newInstance(QStringLiteral("first"), PrimitiveDataType::UInt32, lwc)
-                    << PrimitiveFactory::newInstance(QStringLiteral("second"), PrimitiveDataType::UInt32, lwc);
+    structsChildren << PrimitiveFactory::newInstance(QLatin1String("first"), Type_UInt32, lwc)
+            << PrimitiveFactory::newInstance(QLatin1String("second"), Type_UInt32, lwc);
 
-    StructureDataInformation* structs = new StructureDataInformation(QStringLiteral("vals"), structsChildren);
+    StructureDataInformation* structs = new StructureDataInformation(QLatin1String("vals"), structsChildren);
 
     complexSize = 64;
-    complex = new ArrayDataInformation(QStringLiteral("complex"), 0, structs);
+    complex = new ArrayDataInformation(QLatin1String("complex"), 0, structs);
     complexTop = new TopLevelDataInformation(complex);
 
     QCOMPARE(complex->isArray(), true);
@@ -108,7 +117,8 @@ void ArrayDataInformationTest::testResizeHelper(ArrayDataInformation* array, Top
 
     array->setArrayLength(newsize);
     QCOMPARE(array->length(), postsize);
-    if (insertCalled) {
+    if (insertCalled)
+    {
         QCOMPARE(spyAboutToInsert.size(), 1);
         QCOMPARE(spyInserted.size(), 1);
 
@@ -120,7 +130,8 @@ void ArrayDataInformationTest::testResizeHelper(ArrayDataInformation* array, Top
         QCOMPARE(spyInserted[0][1].toUInt(), insertFirstArg);
         QCOMPARE(spyInserted[0][2].toUInt(), insertSecondArg);
     }
-    if (removeCalled) {
+    if (removeCalled)
+    {
         QCOMPARE(spyAboutToRemove.size(), 1);
         QCOMPARE(spyRemoved.size(), 1);
 
@@ -134,6 +145,7 @@ void ArrayDataInformationTest::testResizeHelper(ArrayDataInformation* array, Top
     }
 }
 
+
 void ArrayDataInformationTest::testResize()
 {
     testResizeHelper(primitive, primitiveTop);
@@ -167,6 +179,9 @@ void ArrayDataInformationTest::cleanupTestCase()
     delete primitiveTop;
 }
 
-QTEST_GUILESS_MAIN(ArrayDataInformationTest)
+
+
+QTEST_MAIN(ArrayDataInformationTest)
+
 
 #include "arraydatainformationtest.moc"
