@@ -23,21 +23,20 @@
 #ifndef ABSTRACTBYTEARRAYCHECKSUMPARAMETERSET_H
 #define ABSTRACTBYTEARRAYCHECKSUMPARAMETERSET_H
 
-#include <QScopedPointer>
 
 class AbstractByteArrayChecksumParameterSet
 {
-protected:
+  protected:
     AbstractByteArrayChecksumParameterSet();
-
-public:
+  public:
     virtual ~AbstractByteArrayChecksumParameterSet();
 
-public:
+  public:
     virtual const char* id() const = 0;
 
-private:
-    QScopedPointer<class AbstractByteArrayChecksumParameterSetPrivate> const d;
+  protected:
+    class Private;
+    Private* const d;
 };
 
 #endif
