@@ -23,24 +23,26 @@
 #ifndef PRINTCOLUMNSTYLIST_H
 #define PRINTCOLUMNSTYLIST_H
 
-// Okteta gui
-#include <okteta/abstractcolumnstylist.h>
+// lib
+#include <abstractcolumnstylist.h>
 // Qt
-#include <QPalette>
+#include <QtGui/QPalette>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 class PrintColumnStylist : public Okteta::AbstractColumnStylist
 {
-public:
+  public:
     PrintColumnStylist();
-    ~PrintColumnStylist() override;
+    virtual ~PrintColumnStylist();
 
-public: // AbstractColumnStylist API
-    const QPalette& palette() const override;
+  public: // AbstractColumnStylist API
+    virtual const QPalette& palette() const;
 
-protected:
-    QPalette mPalette = {Qt::white};
+  protected:
+    QPalette mPalette;
 };
 
 }
