@@ -24,15 +24,17 @@
 #define BYTEARRAYDOCUMENTTEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace Kasten {
+
+namespace Kasten2
+{
 
 class ByteArrayDocumentTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testCreateNew();
     void testSetTitle();
 };
