@@ -24,19 +24,22 @@
 #define BYTEARRAYDATAGENERATORFACTORY_H
 
 // lib
-#include <kasten/okteta/oktetakastengui_export.h>
+#include "oktetakastengui_export.h"
 
-template <class T> class QList;
+template<class T> class QList;
 
-namespace Kasten {
+
+namespace Kasten2
+{
 class AbstractModelDataGenerator;
 
+
 class OKTETAKASTENGUI_EXPORT ByteArrayDataGeneratorFactory
 {
-private:
+  private:
     ByteArrayDataGeneratorFactory();
 
-public:
+  public:
     static QList<AbstractModelDataGenerator*> createDataGenerators();
 };
 
